@@ -64,7 +64,7 @@ _typeinfo_map = {
     "NMTOKENS": minidom.TypeInfo(None, "nmtokens"),
     }
 
-class ElementInfo(object):
+class ElementInfo:
     __slots__ = '_attr_info', '_model', 'tagName'
 
     def __init__(self, tagName, model=None):
@@ -125,7 +125,7 @@ def _parse_ns_name(builder, name):
     if len(parts) == 3:
         uri, localname, prefix = parts
         prefix = intern(prefix, prefix)
-        qname = "%s:%s" % (prefix, localname)
+        qname = f"{prefix}:{localname}"
         qname = intern(qname, qname)
         localname = intern(localname, localname)
     elif len(parts) == 2:
@@ -491,7 +491,7 @@ class ExpatBuilder:
 # where allowed.
 _ALLOWED_FILTER_RETURNS = (FILTER_ACCEPT, FILTER_REJECT, FILTER_SKIP)
 
-class FilterVisibilityController(object):
+class FilterVisibilityController:
     """Wrapper around a DOMBuilderFilter which implements the checks
     to make the whatToShow filter attribute work."""
 
@@ -549,7 +549,7 @@ class FilterVisibilityController(object):
         }
 
 
-class FilterCrutch(object):
+class FilterCrutch:
     __slots__ = '_builder', '_level', '_old_start', '_old_end'
 
     def __init__(self, builder):
@@ -561,6 +561,7 @@ class FilterCrutch(object):
         parser.StartElementHandler = self.start_element_handler
         parser.EndElementHandler = self.end_element_handler
 
+
 class Rejecter(FilterCrutch):
     __slots__ = ()
 
@@ -936,6 +937,7 @@ class ParseEscape(Exception):
     """Exception raised to short-circuit parsing in InternalSubsetExtractor."""
     pass
 
+
 class InternalSubsetExtractor(ExpatBuilder):
     """XML processor which can rip out the internal document type subset."""
 
